@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef __PY_DOUBLE_PINYIN_EDITOR_H_
 #define __PY_DOUBLE_PINYIN_EDITOR_H_
@@ -29,33 +29,11 @@ class DoublePinyinEditor : public PinyinEditor {
 
 public:
     DoublePinyinEditor (PinyinProperties & props, Config & config);
-
-    gboolean insert (gint ch);
-
-    gboolean removeCharBefore (void);
-    gboolean removeCharAfter (void);
-    gboolean removeWordBefore (void);
-    gboolean removeWordAfter (void);
-
-    gboolean moveCursorLeft (void);
-    gboolean moveCursorRight (void);
-    gboolean moveCursorLeftByWord (void);
-    gboolean moveCursorRightByWord (void);
-    gboolean moveCursorToBegin (void);
-    gboolean moveCursorToEnd (void);
+    virtual ~DoublePinyinEditor ();
 
     /* override virtual functions */
     gboolean processKeyEvent (guint keyval, guint keycode, guint modifiers);
-    void reset (void);
     void updateAuxiliaryTextAfter (String &buffer);
-
-protected:
-    gboolean updatePinyin (gboolean all);
-
-private:
-    const Pinyin *isPinyin (gint i, gint j);
-    const Pinyin *isPinyin (gint i);
-
 };
 
 };
