@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include "PYPinyinEngine.h"
 #include <string>
@@ -123,22 +123,18 @@ PinyinEngine::processKeyEvent (guint keyval, guint keycode, guint modifiers)
                 case IBUS_grave:
                     m_input_mode = MODE_PUNCT;
                     break;
-#ifdef IBUS_BUILD_LUA_EXTENSION
                 case IBUS_i:
                     // do not enable lua extension when use double pinyin.
                     if (PinyinConfig::instance ().doublePinyin ())
                         break;
                     m_input_mode = MODE_EXTENSION;
                     break;
-#endif
-#ifdef IBUS_BUILD_ENGLISH_INPUT_MODE
                 case IBUS_v:
                     // do not enable english mode when use double pinyin.
                     if (PinyinConfig::instance ().doublePinyin ())
                         break;
                     m_input_mode = MODE_ENGLISH;
                     break;
-#endif
                 }
             }
             else {
@@ -317,4 +313,3 @@ PinyinEngine::connectEditorSignals (EditorPtr editor)
 }
 
 };
-
